@@ -1,6 +1,6 @@
 package XML::XPath::Parser;
 
-$VERSION = '1.40';
+$VERSION = '1.41';
 
 use strict; use warnings;
 use vars qw/
@@ -42,8 +42,12 @@ use XML::XPath::NodeSet;
         'self' => 'element',
         );
 
-$NCName = '([A-Za-z_][\w\\.\\-]*)';
-$QName = "($NCName:)?$NCName";
+my $NameStartCharClassBody = "a-zA-Z_\\xC0-\\xD6\\xD8-\\xF6\\xF8-\\x{2FF}\\x{370}-\\x{37D}\\x{37F}-\\x{1FFF}\\x{200C}-\\x{200D}\\x{2070}-\\x{218F}\\x{2C00}-\\x{2FEF}\\x{3001}-\\x{D7FF}\\x{F900}-\\x{FDCF}\\x{FDF0}-\\x{FFFD}\\x{10000}-\\x{EFFFF}";
+my $NameCharClassBody = "${NameStartCharClassBody}\\-.0-9\\xB7\\x{300}-\\x{36F}\\x{203F}-\\x{2040}";
+my $Name = "(?:[$NameStartCharClassBody][$NameCharClassBody]*)";
+
+$NCName = $Name;
+$QName  = "$NCName(?::$NCName)?";
 $NCWild = "${NCName}:\\*";
 $QNWild = "\\*";
 $NODE_TYPE = '((text|comment|processing-instruction|node)\\(\\))';
